@@ -40,8 +40,8 @@ double bcxmds( const size_t n, double** delta, const size_t p, double** z, doubl
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dssq( n * n, &gamma[1][1], 1 );
   double fold = dsse( n * n, &gamma[1][1], 1, &d[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -184,8 +184,8 @@ double bcxwgtmds( const size_t n, double** delta, double** w, const size_t p, do
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dwssq( n * n, &gamma[1][1], 1, &w[1][1], 1 );
   double fold = dwsse( n * n, &gamma[1][1], 1, &d[1][1], 1, &w[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -331,8 +331,8 @@ double fxdbcxmds( const size_t n, double** delta, const size_t p, double** z, in
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dssq( n * n, &gamma[1][1], 1 );
   double fold = dsse( n * n, &gamma[1][1], 1, &d[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -481,8 +481,8 @@ double fxdbcxwgtmds( const size_t n, double** delta, double** w, const size_t p,
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dwssq( n * n, &gamma[1][1], 1, &w[1][1], 1 );
   double fold = dwsse( n * n, &gamma[1][1], 1, &d[1][1], 1, &w[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -661,8 +661,8 @@ double varbcxmds( const size_t n, double** delta, const size_t p, const size_t h
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dssq( n * n, &gamma[1][1], 1 );
   double fold = dsse( n * n, &gamma[1][1], 1, &d[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -844,8 +844,8 @@ double varbcxwgtmds( const size_t n, double** delta, double** w, const size_t p,
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dwssq( n * n, &gamma[1][1], 1, &w[1][1], 1 );
   double fold = dwsse( n * n, &gamma[1][1], 1, &d[1][1], 1, &w[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
