@@ -45,8 +45,8 @@ double ordmds( const size_t n, double** delta, const size_t p, double** z, doubl
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dssq( n * n, &gamma[1][1], 1 );
   double fold = dsse( n * n, &gamma[1][1], 1, &d[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -200,8 +200,8 @@ double ordwgtmds( const size_t n, double** delta, double** w, const size_t p, do
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dwssq( n * n, &gamma[1][1], 1, &w[1][1], 1 );
   double fold = dwsse( n * n, &gamma[1][1], 1, &d[1][1], 1, &w[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -358,8 +358,8 @@ double fxdordmds( const size_t n, double** delta, const size_t p, double** z, in
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dssq( n * n, &gamma[1][1], 1 );
   double fold = dsse( n * n, &gamma[1][1], 1, &d[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -519,8 +519,8 @@ double fxdordwgtmds( const size_t n, double** delta, double** w, const size_t p,
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dwssq( n * n, &gamma[1][1], 1, &w[1][1], 1 );
   double fold = dwsse( n * n, &gamma[1][1], 1, &d[1][1], 1, &w[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -709,8 +709,8 @@ double varordmds( const size_t n, double** delta, const size_t p, const size_t h
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dssq( n * n, &gamma[1][1], 1 );
   double fold = dsse( n * n, &gamma[1][1], 1, &d[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
@@ -902,8 +902,8 @@ double varordwgtmds( const size_t n, double** delta, double** w, const size_t p,
   dcopy( n * n, &delta[1][1], 1, &gamma[1][1], 1 );
   double scale = dwssq( n * n, &gamma[1][1], 1, &w[1][1], 1 );
   double fold = dwsse( n * n, &gamma[1][1], 1, &d[1][1], 1, &w[1][1], 1 ) / scale;
-  double fhalf = 0.0;
-  double fnew = 0.0;
+  double fhalf = fold;
+  double fnew = fold;
 
   // echo intermediate results
   if ( echo == true ) echoprogress( 0, fold, fold, fold ); 
